===============================
scikit-ci
===============================

.. image:: https://readthedocs.org/projects/scikit-ci/badge/?version=latest
    :target: http://scikit-ci.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

.. image:: https://ci.appveyor.com/api/projects/status/5to6lvgaqcrck675?svg=true
    :target: https://ci.appveyor.com/project/scikit-build/scikit-ci/branch/master

.. image:: https://circleci.com/gh/scikit-build/scikit-ci/tree/master.svg?style=svg
    :target: https://circleci.com/gh/scikit-build/scikit-ci/tree/master

.. image:: https://img.shields.io/travis/scikit-build/scikit-ci.svg?maxAge=2592000
    :target: https://travis-ci.org/scikit-build/scikit-ci

.. image:: https://codecov.io/gh/scikit-build/scikit-ci/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/scikit-build/scikit-ci

scikit-ci enables a centralized and simpler CI configuration for Python
extensions.

By having ``appveyor.yml``, ``circle.yml`` and ``.travis.yml`` calling
the same scikit-ci command-line executable, all the CI steps for all
service can be fully described in one ``scikit-ci.yml`` file.

* Free software: Apache Software license
* Documentation: http://scikit-ci.readthedocs.org
* Source code: https://github.com/scikit-build/scikit-ci
* Mailing list: https://groups.google.com/forum/#!forum/scikit-build
